@@ -6,6 +6,7 @@ from rich.highlighter import ReprHighlighter
 from rich.style import Style
 from rich.syntax import Syntax
 from rich.text import Text
+from .utils import is_selectable
 
 highlighter = ReprHighlighter()
 
@@ -132,14 +133,23 @@ class CachedObject:
                     repr_key = highlighter(str(repr(key)))
                 repr_val = highlighter(str(type(val)))
 
-                if callable(val):
+                if not is_selectable(val):
                     repr_val.style = Style(dim=True, italic=True)
 
                 line = Text("  ") + repr_key + Text(": ") + repr_val
                 line.overflow = "ellipsis"
                 self.dict_lines.append(line)
 
-            self.num_keys = len(self.obj.keys())
+        if type(self.obj) == list:
+            self.list_lines: List[Text] = []
+            for index, item in enumerate(self.obj):
+                item_type = highlighter(str(type(item)))
+                line = (
+                    Text(" [") + console.render_str(str(index)) + Text("] ") + item_type
+                )
+                if not is_selectable(item):
+                    line.style = Style(dim=True, italic=True)
+                self.list_lines.append(line)
 
     @property
     def title(self):
@@ -162,6 +172,8 @@ class CachedObject:
         # Set the default selected cached attribute
         if type(self.obj) == dict:
             self.selected_cached_obj = CachedObject(self.obj[list(self.obj.keys())[0]])
+        elif type(self.obj) == list:
+            self.selected_cached_obj = CachedObject(self.obj[0])
         elif self.plain_public_attributes:
             self.selected_cached_obj = self.cached_attributes[
                 self.plain_public_attributes[0]
